@@ -1,6 +1,5 @@
 """Response processor"""
 
-from collections import abc
 from copy import deepcopy
 from functools import wraps
 import http
@@ -135,11 +134,14 @@ class ResponseMixin:
             Example: ::
 
                 @staticmethod
-                def _doc_schema(schema):
+                def _make_doc_response_schema(schema):
                     if schema:
-                        return {'type': 'success', 'data': schema}
-                    else:
-                        return None
+                        return type(
+                            'Wrap' + schema.__class__.__name__,
+                            (ma.Schema, ),
+                            {'data': ma.fields.Nested(schema)},
+                        )
+                    return None
         """
         return schema
 
@@ -152,22 +154,17 @@ class ResponseMixin:
             Example: ::
 
                 @staticmethod
-                def _prepare_response_content:
-                    return {'type': 'success', 'data': schema}
+                def _prepare_response_content(data):
+                    if data is not None:
+                        return {'data': data}
+                    return None
         """
         return data
 
     @staticmethod
     def _prepare_response_doc(doc, doc_info, spec, **kwargs):
         operation = doc_info.get('response', {})
-
-        responses = {
-            c: r for c, r in operation.get('responses', {}).items()
-            if isinstance(r, abc.Mapping)
-        }
-
-        for resp in responses.values():
-            prepare_response(resp, spec, DEFAULT_RESPONSE_CONTENT_TYPE)
-
+        for response in operation.get('responses', {}).values():
+            prepare_response(response, spec, DEFAULT_RESPONSE_CONTENT_TYPE)
         doc = deepupdate(doc, operation)
         return doc
